Codec

com.digitalasset.transcode.Codec
See theCodec companion object
trait Codec[A] extends Encoder[A], Decoder[A]

Codec encodes and decodes target protocol to and from an intermediary com.digitalasset.transcode.schema.DynamicValue representation. Arbitrary codecs can be composed together to create direct interoperability Converters.

Attributes

Companion
object
Graph
Supertypes
trait Decoder[A]
trait Encoder[A]
class Object
trait Matchable
class Any
Self type
Codec[A]

Members list

Value members

Concrete methods

def dimap[B](f: A => B, g: B => A): Codec[B]

Inherited and Abstract methods

Attributes

Inherited from:
Encoder

Attributes

Inherited from:
Decoder