com.digitalasset.transcode.Codec
See theCodec companion object
Codec encodes and decodes target protocol to and from an intermediary com.digitalasset.transcode.schema.DynamicValue representation. Arbitrary codecs can be composed together to create direct interoperability Converters.
Attributes
Members list
In this article